package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M35J0``,````$````__\``+@`````````0```````````````````````````
M````````````````````^`````X?N@X`M`G-(;@!3,TA5&AI<R!P<F]G<F%M
M(&-A;FYO="!B92!R=6X@:6X@1$]3(&UO9&4N#0T*)`````````!QTR4(-;)+
M6S6R2ULULDM;6JU!6SZR2UNVKD5;-[)+6UJM3ULWLDM;5ZU86S&R2UM.KD=;
M-[)+6S6R2EMZLDM;RI)/6S:R2UL#E$%;-[)+6XVT35LTLDM;4FEC:#6R2UL`
M``````````````````````````````!010``3`$$`,\ZUDD``````````.``
M#P$+`08``#````"@````````C#D````0````0`````!````0````$```!```
M```````$``````````#@````$```UM`!``,``````!```!``````$```$```
M`````!```````````````.R@``!D`````,```-`1````````````````````
M```````````````P00``'```````````````````````````````````````
M````````````````````0```)`$`````````````````````````````````
M`"YT97AT````S"H````0````,````!```````````````````"```&`N<F1A
M=&$``+QF````0````'````!```````````````````!```!`+F1A=&$```!P
M!````+`````0````L```````````````````0```P"YR<W)C````T!$```#`
M````(````,```````````````````$```,``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`&AP04``:*`X0`!H5$%``.B&*```4.AZ*```@\00PS/`PU6+[('L"`0``%-6
M5VB804``Z*@!``")1?R-A?C[___'!"0`!```,]M04_\5$$!``(7`#X5,`0``
M_S40L$``BW4(5O\5B$!``%E9A<!6=!-HB$%``.CS`0``68O&6>E7`0``Z+XH
M``#_-12P0`"+/9!`0`")1?C_=0S_UX/$#(OP._,/A!\!```X'G4%OH1!0``Y
M7?QT$U;_=?SH@"@``%F%P%D/A,L```!6Z'8H``"*5##_68L-$+!``#H1=0I(
MB!P&BE0&_^OLBU7X_W4(C400`3T`!```#XW-````45:-A?C[__]H?$%``%#_
M%:1`0`#H@R<``%#HCR<``(LPZ'8G``!0Z'PG``"#Q!Q0C87X^___4.A@)P``
M4.AL)P``6?\P_U90@\0,A<!U2.A()P``4.A.)P``9HM`!EEF)0#P9CT`@'4N
MZ"XG``!0Z#HG``"+,%F-A?C[__]J`5#H%R<``%#H(R<``%G_,/\6@\0,A<!T
M$/\U%+!``%/_UUE9Z?K^__^-A?C[__]0:(A!0`#HMP```(V%^/O__U#_%41`
M0`"#Q`SK$O]U"&B(04``Z)@```"+10A965]>6\G#58OLC44(4/]U".@$````
M65E=PU6+[%%35HMU"%>%]G1FBQV$0$``_].#.`!T68H.B\:$R70+@/D]=`:*
M2`%`Z_$KQHE%_/_3BS"+/H7_=#?_=?S_=0A7_Q5`0$``@\0,A<!U"8M%_(`\
M!SUT!8/&!.O8_],K,(M%#,'^`HDPBT7\C40'`>L",\!?7EO)PU6+[%%1BT4,
M@#@]=0/_10Q35E?_=0SHOB8``(M="(E%^(U%_%!3Z%K___^+-81`0`"+^(/$
M#(7_=")7Z)DF```[1?A9#X++````BTT,B@&(!T=!A,!U]ND\`0``_]:+`#/_
M,\DY"'0&@\`$1^OV.0U0M$``=$#HLB4``%#HQ"4``(L868T$O0@```!0_];_
M,.B8)0``4.BJ)0``6?\P_U,$@\0,B]C_UHD8_]:#.`!U5>FQ````QP50M$``
M`0```.AH)0``4.AZ)0``BQA9C02]"````%#H4B4``%#H9"4``%G_,/\3B]A9
MA=M9='F+Q\'@`E#_UO\P4_\5@$!``(/$#/_6B1C_UHL`BUT(@V2X!`")??R*
M`XO[A,!T"CP]=`:*1P%'Z_+H`24``%#H$R4``(L0BT7X*_M9B54(C40'`E#H
MYB0``%#H^"0``%G_,(M%"/\068OX6?_6BP"+3?R%_XD\B'4%@\C_ZR[_UHL`
MBTW\BP2(B@M#A,F("'0(@/D]=`-`Z^^+50S&`#U`B@J("$!"A,EU]C/`7UY;
MR<.+1"0$5HOPB\B*`(3`=!>+%1"P0`"*$CK"=0.-<0&*00%!A,!U\8O&7L-6
MBW0D"(7V=&^`/@!T:E;H_"0``(U$,/]9BPT0L$``.\9V%HH1.!!U!4@[QG?W
M.\9V"3@0=`-(Z_4[QG4)B@`Z`70U4>LW2#O&=@:*$#H1=/4KQHU(`H'Y``0`
M`'8$,\!>PT!05KY(L$``5O\5?$!``(/$#(O&7L-HA$%``/\51$!``%E>PU6+
M[(/L)%-65VH(6;YL0D``C7W<:%Q"0`#SI6:EZ`D!``#'!"100D``Z/T```"[
MF$%``%/H\@```+Y$0D``5NCG````OSA"0`!7Z-P```!H+$)``.C2````:(A!
M0`#HR````&@@0D``Z+X```!H%$)``.BT````:`!"0`#HHOS__X/$)(7`=`E0
M5^@B_?__65EH[$%``.B(_/__A<!9=`U0:.!!0`#H!OW__UE9:-!!0`#H;/S_
M_X7`670+4%/H[OS__UE9ZTYHO$%``.A2_/__A<!9=`105NOD:+1!0`#HIB,`
M`+^H04``C5P%Z%?HER,``%!74_\5>$!``(/$%(7`=1)7Z($C```#PU!6Z)_\
M__^#Q`QHI$%``&A<0D``Z(W\__]965]>6\G#58OL48U%_%#_=0CH^_O__UF%
MP%ET'O\5A$!``(L`BTW\C0R(BU$$C4$$A=*)$734B\CK\,G#H1BP0`"#^/]U
M)6A$0D``Z*[[__^%P%ET#XH`A,!T"3PP=`5J`5CK`C/`HQBP0`##58OL@^P@
MN,A"0`!7B_A0B47@QT7DP$)``,=%Z+!"0`#'1>RH0D``QT7PE$)``,=%])!"
M0`")??CHO"(``(7`60^&Q````(U%X%-6B47\5^@^^___B_!9A?8/A(,```!6
MZ)0B``"%P%ET>/]U"%;_%8A`0`!9A<!9=7/HSB$``%#HX"$``/\U%+!``(LX
MZ&<B``!6B]CH7R(``/]U"`/8Z%4B``"#Q!"-1`,"4.B<(0``4.BN(0``6?\P
M_Q=6B_C_-12P0`#_=0AH?$%``%?_%:1`0`!7_W7XZ$/[__^#Q"3K"_]U"%?H
M-?O__UE9@T7\!(M%_(LX5XE]^.CZ(0``A<!9#X=&____7EM?R<-5B^RXX(``
M`.CI(0``@V7\`%:XD$)``&B804``QT78<$-``,=%W%!!0`#'1>"$04``B47D
MQT7`X$%``,=%Q&A#0`#'1<A@0T``QT7,6$-``,=%T%1#0`")1=3'1>A,0T``
MQT7L0$-``(E%\.@5^O__B_!9A?9T'U;H;R$``(7`67045NAK_O__5O\51$!`
M`%E9Z=<#``!3O@`$``!7B77XZ)L@``!0Z*T@``"+.%E6Z(P@``!0Z)X@``!9
M_S#_%UE9C4WX45#_%0!`0`#H\_?__XO8A=N)7?AU/8U]Z(LW5N@'(0``A<!9
M=B!6Z)7Y__^%P%ET"U#_%41`0`!9B47XBUWX@\<$A=MTTX7;=0G'1?@X0T``
MZT.`.P"+\W0\OP<!``"A9$!``(,X`7X/#[X&5U#_%6A`0`!96>L1BPUL0$``
M#[X&BPEFBP1!(\>%P'4#Q@9?1H`^`'7)C7W`BS=6Z(<@``"%P%EV+%;H%?G_
M_XOP687V=!96Z`H9``"%P%ET"U;_%41`0`!9B47\@\<$@WW\`'3'@WW\`(LU
MI$!``'5Y:#!#0`#HV?C__XO8687;=&CHB!\``%#HFA\``(LX4^@F(```68/`
M!EE0Z&\?``!0Z($?``!9_S#_%XOX4V@H0T``5__65^B:&```@\08A<!T!8E]
M_.LBZ$(?``!0Z%0?``"+&%E7Z#,?``!0Z$4?``!9_S#_4PA968-]_`!U+XU=
MV(L[5^C`'P``A<!9=A]7Z%`8``"%P%ET"U?_%41`0`!9B47\@\,$@WW\`'34
M_W7XZ)0?``#_=?R+^.B*'P``NR!#0``#^%/H?1\``&B00D```_CH<1\``(V\
M!P`$``#HN1X``%#HRQX``(L0@\04B57T5^BE'@``4.BW'@``6?\PBT7T_Q#_
M=?B+^%/_-1"P0`#_=?QH%$-``%?_UE?_%7!`0`!HJ$)``.BT]___BUT(@\0H
MA<!T&5#_%41`0`!0_S/HW?7__X/$#(E%"(7`=06+`XE%".C%^___A<`/A4X"
M``#H-1X``%#H01X``(L8QP0D`(```/]U".@>'@``4.@J'@``6?\P_U,\@\0,
MB44(A<`/A!@"``#H_QT``%#H"QX``%F+&&H":O]J[O]U".CH'0``4.CT'0``
M6?\P_U,PZ-<=``!0Z.,=``"+&(/$&(V%('___VH&4/]U".B['0``4.C''0``
M6?\P_U-$@\00@+T@?___``^%SP```("](7___T,/A<(```"`O2)___]!#X6U
M````@+TC?___0P^%J````("])'___T@/A9L```"`O25___]%#X6.````Z%D=
M``!0Z&4=``!9BQAJ`FK_:L;_=0CH0AT``%#H3AT``%G_,/]3,.@Q'0``4.@]
M'0``BQB#Q!B-A2!___]J*5#_=0CH%1T``%#H(1T``%G_,/]31(V%('___VB0
M0D``4/\U$+!``%=H!$-``%?_UH/$*%=HF$%``.BS]O__5^B-^O__@\0,B\=?
M6U[)PXV%(/___U#HG0$``.B_'```4.C+'```65F+&(V%('___V@`@```4/]U
M".BA'```4.BM'```6?\P_U-$@\00A<!^)%"-A2!___]0C84@____4.B%`0``
MZ'4<``!0Z($<``"#Q!#KL^AE'```4.AQ'```BQA9_W4(Z%0<``!0Z&`<``!9
M_S#_4Q"-A2#___]0C46L4.@B%```C46`@\00,]N)10@/MD0=K%!H_$)``/]U
M"/_6@T4(`H/$#$.#^Q1\XXU%@&B00D``@&6H`%#_-1"P0`!7:`1#0`!7_]:#
MQ!CI`?___X-E"`!7Z(X<``#'!"2D04``:$1"0`")1?3HH?7__UE9:)!"0`#H
MPAL``%#HVAL``(L8Z+4;``!0Z,T;``#_,/]3:(/$#%#_-1"P0`!7:.Q"0`!7
M_]97_Q5P0$``@\0<@_C_#X69_O___Q5T0$``@S@1#X6*_O__BT7T:)!"0`"`
M)#@`_T4(_W4(Z%X;``!0Z'8;``"+&.A1&P``4.AI&P``_S#_4VB#Q`Q0_S40
ML$``5VC80D``5__65_\5<$!``(/$(.N:BT0D!#/)QP`!(T5GQT`$B:O-[\=`
M"/[<NIC'0`QV5#(0QT`0\.'2PXE(%(E(&(E(7,-5B^Q3BUT05HMU"%>+3A2-
M!-D[P7,#_T88B484B\/!Z!T!1AB+1ER%P'0T:D!?*_@[^WX"B_N+1EQ7_W4,
MC40&'%#HE!L```%]#`%^7(/$#"O?@WY<0'5+5NA*````68/[0'PLB_O![P:+
MQ_?8P>`&`]AJ0(U&'/]U#%#H6QL``(-%#$!6Z!X```"#Q!!/=>)3C48<_W4,
M4.@^&P``@\0,B5Y<7UY;7<-5B^R![%0!``"+10A35E>-4!R-M:S^___'10@0
M````BPJ#P@2+^8O9@><``/\`P>L0"_N+V8'C`/\``,'A$`O9P>\(P>,("_N)
M/H/&!/]-"'7-:D"-E;3^__]>BTHL,TH8,TKX,PJ#P@2+^0/)P>\?"_E.B7HT
M=>.+>`2+4`B+<`R+"(O?(]?WTR/>B_$+VHO1P>H;P>8%"]:+<!`#\P/6B[6L
M_O__C90RF7F"6HOWP>8>P>\""_>+^??7(W@(B77L(_&+V@O^B_+!ZQO!Y@4+
MWHNUL/[__P/W`]Z+<`R-O#.9>8):B_&+V8E]^,'F'L'K`@OSB]KWTR-=[(EU
M_"/R"]Z+M;3^__^)70B+W\'K&\'G!0O?BWT(`_>+^L'G'L'J`@/>BW`("_J+
M5?B-M#.9>8):BUWX]](C5?PCWXE]](O^"].+WL'O&\'C!0O[BYVX_O__`]H#
M^XM5[(V<%YEY@EJ+??B+UXE=",'B'L'O`@O7B_[WUR-]](E5^"/6"_J+T\'J
M&\'C!0O3BYV\_O__`]^+??P#TXV4.IEY@EJ+_L'G'L'N`@O^BW4(]]8C=?B)
M??`C?0B+VL'C!0OWB_K![QL+^XN=P/[__P/>BW7T`_N-G#>9>8):BWT(B_>)
M7?S!YA[![P(+]XOZ]]<C??")=0@C\@O^B_/![AO!XP4+\XN=Q/[__P/?BWWX
M`_.-M#Z9>8):B_K!YQ[!Z@(+^HM5_/?2(U4(B7WL(WW\B][!XP4+UXO^P>\;
M"_N+G<C^__\#VHM5\`/[C9P7F7F"6HM]_(O7B5WXP>(>P>\""]>+_O?7(WWL
MB57\(]8+^HO3P>H;P>,%"].+G<S^__\#WXM]"`/3BUWXC90ZF7F"6HO^P><>
MP>X""_Z+=?CWUB-U_"/?B7WTB_H+\XO:P>\;P>,%"_N+G=#^__\#WHMU[`/[
MC9PWF7F"6HM]^(OWB5T(P>8>P>\""_>+^O?7(WWTB77X(_(+_HOSP>X;P>,%
M"_.+G=3^__\#WXM]_`/SC;0^F7F"6HOZP><>P>H""_J+50CWTB-5^(E]\"-]
M"(O>P>,%"]>+_L'O&PO[BYW8_O__`]J+5?0#^XV<%YEY@EJ+?0B+UXE=_,'B
M'L'O`@O7B_[WUR-]\(E5""/6"_J+T\'J&\'C!0O3BYW<_O__`]^+??@#TXV4
M.IEY@EJ+_L'G'L'N`@O^BW7\]]8C=0B)?>PC??R+VL'C!0OWB_K![QL+^XN=
MX/[__P/>BW7P`_N-G#>9>8):BWW\B_>)7?C!YA[![P(+]XOZ]]<C?>R)=?PC
M\@O^B_/![AO!XP4+\XN=Y/[__P/?BWT(`_.+7?B-M#Z9>8):B_K!YQ[!Z@(+
M^HM5^/?2(U7\B7WT(]^+_@O3B][![QO!XP4+^XN=Z/[__P/:BU7L`_N-G!>9
M>8):BWWXB]>)70C!XA[![P(+UXO^]]<C??2)5?@CU@OZB]/!ZAO!XP4+TXN=
M[/[__P/?BWW\`].-E#J9>8):B_[!YQ[![@(+_HMU"/?6(W7XB7WP(WT(B]K!
MXP4+]XOZP>\;"_N+G?#^__\#WHMU]`/[C9PWF7F"6HM]"(OWB5W\P>8>P>\"
M"_>+^O?7(WWPB74((_(+_HOSP>X;P>,%"_.+G?3^__\#WXM]^`/SC;0^F7F"
M6HOZP><>P>H""_J+5?SWTB-5"(E]["-]_`O7B_[![QN+WL'C!0O[BYWX_O__
M`]J+5?`#^XV<%YEY@EJ+??R+UXE=^,'B'L'O`@O7B_O![QO!XP4+^XM=[(E5
M_#/:BY7\_O__,]X#UXO^`]J+50C!YQ[![@(+_HV4$Z'KV6Z)??2+\HOZBYT`
M____P>X;P><%"_>+??@S??P#WHMU[#-]]`/[C9PWH>O9;HM]^(OWB5T(P>8>
MP>\""_>+^\'O&\'C!8EU^`O[BYT$____,_(S=?0#WXM]_`/SC;0^H>O9;HOZ
MP><>P>H""_J+UHO>B7WPP>H;P>,%"].+7?@SWXN]"/___S-="`/ZBU7T`]^-
MG!.AZ]ENBWT(B5W\B]?!XA[![P(+UXO[P>\;P>,%"_N+7?")50@SVHN5#/__
M_S/>`]>+_@/:BU7XP><>P>X"C903H>O9;@O^B_*+VL'N&\'C!0OSBUT(B7WL
M,]^+O1#___\S7?P#_HMU\`/?BWW\C9PSH>O9;HOWP>8>P>\""_>+^XE=^(EU
M_,'O&\'C!0O[BUWL,]Z+M13___\SV@/WB_H#WHMU",'G'L'J`@OZC;0SH>O9
M;HE]](O6B_Z+G1C____!ZAO!YP4+UXM]^#-]_`/:BU7L,WWT`_N-G!>AZ]EN
MBWWXB]>)70C!XA[![P(+UXE5^(O[,]8S5?3![QO!XP4+^XN='/___P/?BWW\
M`].-E#JAZ]ENB_[!YQ[![@(+_HORB]J)??#![AO!XP4+\XM=^#/?B[T@____
M,UT(`_Z+=?0#WXM]"(V<,Z'KV6Z+]\'F'L'O`@OWB_N)7?R)=0C![QO!XP4+
M^XM=\#/>B[4D____,]H#]P/>BW7XB_K!YQ[!Z@*-M#.AZ]EN"_J+UHO>P>H;
MP>,%"].+70B)?>PSWXN]*/___S-=_`/ZBU7P`]^+??R-G!.AZ]ENB]?!XA[!
M[P(+UXO[B5WXB57\P>\;P>,%"_N+7>PSVHN5+/___S/>`]>+_@/:BU4(P><>
MP>X""_Z-E!.AZ]ENB7WTB_*+^HN=,/___\'N&\'G!0OWBWWX,WW\`]Z+=>PS
M??0#^XV<-Z'KV6Z+??B+]XE=",'F'L'O`@OWB_O![QO!XP6)=?@+^XN=-/__
M_S/R,W7T`]^+??P#\XVT/J'KV6Z+^L'G'L'J`@OZB]:+WHE]\,'J&\'C!0O3
MBUWX,]^+O3C___\S70@#^HM5]`/?BWT(C9P3H>O9;HO7P>(>P>\""]>+^XE=
M_(E5",'O&\'C!0O[BUWP,]J+E3S___\SW@/7`]J+5?B-O!.AZ]ENB];!XA[!
M[@(+UHOWB]_![AO!XP4+\XM="(E5[#/:BY5`____,UW\`]:+=?P#VHM5\(V<
M$Z'KV6Z+UL'B'L'N`@O6B_.)7?B)5?S![AO!XP4+\XM=[#/:BY5$____,]\#
MUHOW`]J+50C!YA[![P(+]XV4$Z'KV6Z)=?2+\HOZBYU(____P>X;P><%"_>+
M??@S??P#WHMU[#-]]`/[C;0WH>O9;HM]^(EU"(OWP>8>P>\""_>+^@M]](M=
M"(EU^"/^B_(C=?3!XP4+_HMU",'N&POSBYU,____`]^+??P#\XVT/MR\&X^+
M^L'G'L'J`@OZB]>)??`+50@C5?@C?0B+W@O7B_[![QO!XP4+^XN=4/___P/:
MBU7T`_N-G!?<O!N/BWT(B]>)7?S!XA[![P(+UXOZB54("_XCUB-]\`OZB]/!
MZAO!XP4+TXN=5/___P/?BWWX`].-E#K<O!N/B_[!YQ[![@(+_HO:B_>)?>P+
M=?PC??S!XP4C=0@+]XOZP>\;"_N+G5C___\#WHMU\`/[C9PWW+P;CXM]_(OW
MB5WXP>8>P>\""_>+_HEU_`OZ(_(C?>P+_HOSP>X;P>,%"_.+G5S___\#WXM]
M"`/SC;0^W+P;CXOZP><>P>H""_J+5?R)??2+7?P+UR-5^"/?B_X+TXO>P>\;
MP>,%"_N+G6#___\#VHM5[`/[C907W+P;CXM]^(E5"(O7P>(>P>\""]>+_@M]
M](M="(E5^"/ZB]8C5?3!XP4+^HM5",'J&PO3BYUD____`]^+??P#TXV4.MR\
M&X^+_L'G'L'N`@O^B]J+]XE]\`MU""-]",'C!2-U^`OWB_K![QL+^XN=:/__
M_P/>BW7T`_N-G#?<O!N/BWT(B_>)7?S!YA[![P(+]XO^B74("_HC\B-]\`O^
MB_/![AO!XP4+\XN=;/___P/?BWWX`_.-M#[<O!N/B_K!YQ[!Z@(+^HO>B]>)
M?>P+5?PC??S!XP4C50@+UXO^P>\;"_N+G7#___\#VHM5\`/[C9P7W+P;CXM]
M_(O7B5WXP>(>P>\""]>+^HE5_`O^(]8C?>P+^HO3P>H;P>,%"].+G73___\#
MWXM]"`/3BUW\C90ZW+P;CXO^P><>P>X""_Z+=?P+]R/?(W7XB7WTB_H+\XO:
MP>\;P>,%"_N+G7C___\#WHMU[`/[C;0WW+P;CXM]^(EU"(OWP>8>P>\""_>+
M^@M]](M="(EU^"/^B_(C=?3!XP4+_HMU",'N&POSBYU\____`]\#\XM]_(VT
M/MR\&X^+^L'G'L'J`@OZB]Z+UXE]\`M5""-]",'C!2-5^`O7B_[![QL+^XM=
M@`/:BU7T`_N-G!?<O!N/BWT(B]>)7?S!XA[![P(+UXOZB54("_XCUB-]\`OZ
MB]/!ZAO!XP4+TXM=A`/?BWWX`].-E#K<O!N/B_[!YQ[![@(+_HO:B_>)?>P+
M=?PC??S!XP4C=0@+]XOZP>\;"_N+78@#WHMU\`/[C9PWW+P;CXM]_(OWB5WX
MP>8>P>\""_>+_HEU_`OZ(_(C?>P+_HOSP>X;P>,%"_.+78P#WXM]"`/SBUW\
MC;0^W+P;CXOZP><>P>H""_J+5?P+UR/?(U7XB7WTB_X+TXO>P>\;P>,%"_N+
M79`#VHM5[`/[C907W+P;CXM]^(E5"(O7P>(>P>\""]>+_@M]](M="(E5^"/Z
MB]8C5?3!XP4+^HM5",'J&PO3BUV4`]^+??P#TXV4.MR\&X^+_L'G'L'N`@O^
MB]J+]XE]\`MU""-]",'C!2-U^`OWB_K![QL+^XM=F`/>BW7T`_N-G#?<O!N/
MBWT(B_>)7?S!YA[![P(+]XO[P>\;P>,%"_N+7?`SWHEU"#/:BW6<`_>+^@/>
MBW7XP><>P>H"C;0SUL%BR@OZB]:+WL'J&\'C!0O3BUT(,]^)?>R+?:`S7?P#
M^HM5\`/?BWW\C9P3UL%BRHO7P>(>P>\""]>+^XE=^(E5_,'O&\'C!0O[BUWL
M,]J+5:0SW@/7B_X#VHM5",'G'L'N`@O^C903UL%BRHE]](ORB_J+7:C![AO!
MYP4+]XM]^#-]_`/>BW7L,WWT`_N-G#?6P6+*BWWXB_>)70C!YA[![P(+]XO[
MP>\;P>,%B77X"_N+7:PS\C-U]`/?BWW\`_.-M#[6P6+*B_K!YQ[!Z@(+^HO6
MB]Z)??#!ZAO!XP4+TXM=^#/?BWVP,UT(`_J+5?0#WXM]"(V<$];!8LJ+U\'B
M'L'O`@O7B_N)7?R)50C![QO!XP4+^XM=\#/:BU6T,]X#UP/:BU7XB_[!YQ[!
M[@*-E!/6P6+*"_Z+\HO:P>X;P>,%"_.+70B)?>PSWXM]N#-=_`/^BW7P`]^+
M??R-G#/6P6+*B_?!YA[![P(+]XO[B5WXB77\P>\;P>,%"_N+7>PSWHMUO#/:
M`_>+^@/>BW4(P><>P>H""_J-M#/6P6+*B7WTB]:+_L'J&\'G!0O7BWWXBUW`
M,WW\`]J+5>PS??0#^XV<%];!8LJ+??B+UXE=",'B'L'O`@O7B_O![QO!XP6)
M5?@+^XM=Q#/6,U7T`]^+??P#TXV4.M;!8LJ+_L'G'L'N`@O^B_*+VHE]\,'N
M&\'C!0OSBUWX,]^+?<@S70@#_HMU]`/?BWT(C9PSUL%BRHOWP>8>P>\""_>+
M^XE=_(EU",'O&\'C!0O[BUWP,]Z+=<PSV@/W`]Z+=?B+^L'G'L'J`HVT,];!
M8LH+^HO6B][!ZAO!XP4+TXM="(E][#/?BWW0,UW\`_J+5?`#WXV<$];!8LJ+
M??R)7?B+U\'B'L'O`@O7B_O![QO!XP4+^XM=[(E5_#/:BU74,]X#UXO^`]J+
M50C!YQ[![@(+_HV4$];!8LJ)??2+\HOZBUW8P>X;P><%"_>+??@S??P#WHMU
M[#-]]`/[C9PWUL%BRHM]^(OWB5T(P>8>P>\""_>+^\'O&\'C!8EU^`O[BUW<
M,_(S=?0#WXM]_`/SC;0^UL%BRHOZP><>P>H""_J+UHO>B7WPP>H;P>,%"].+
M7?@SWXM]X#-="`/ZBU7T`]^+?0B-G!/6P6+*B]?!XA[![P(+UXE=_(E5"(O[
MP>\;P>,%"_N+7?`SVHM5Y#/>`]<#VHM5^(O^P><>P>X"C903UL%BRHM="`O^
MB_*)5?0SW\'N&\'B!0ORBU7\,]H#S@/9BTWP`UWHBW7TC8P+UL%BRHD(BT@$
M`\Z)2`2+RL'A'L'J`@O*BU4(`T@(B4@(BT@,`\]?B4@,BT@0`\I>B4@06\G#
M58OL4U:+=0R+1AB+7A2)10R+P\'H`X/@/\9$,!R`0(/X.'XJ:D!9*\B-1#`<
M46H`4.C,"```5NB-[?__:CB-1AQJ`%#HN0@``(/$'.L5:CA9*\B-1#`<46H`
M4.BB"```@\0,BT4,5HO(B$97P>D8B$Y4B\C!Z1"(3E6+R(O#_W4(P>@8B$98
MB\/!Z!"(1EF+P\'I",'H"(A.5HA&6HA>6^@&````65E>6UW#5HMT)`Q6Z!/M
M__^+1"0,68L.P>D8B`B+#L'I$(A(`8L.P>D(B$@"B@Z(2`.+5@2-3@3!ZAB(
M4`2+$<'J$(A0!8L1P>H(B%`&B@F(2`>+5@B-3@C!ZAB(4`B+$<'J$(A0"8L1
MP>H(B%`*B@F(2`N+5@R-3@S!ZAB(4`R+$<'J$(A0#8L1P>H(B%`.B@F(2`^+
M5A"-3A!>P>H8B%`0BQ'!ZA"(4!&+$<'J"(A0$HH)B$@3PU;HLP8``%#HOP8`
M`(LPZ*8&``!0Z*P&``!965#_="0,Z)0&``!0Z*`&``!9_S#_5E"#Q`R%P'5*
MZ'P&``!0Z((&``!FBT`&668E`/!F/0!`=3#H8@8``%#H;@8``(LP66H"_W0D
M#.A.!@``4.A:!@``6?\P_Q:#Q`R%P'4%:@%87L,SP%[#5HMT)`A75NC#X?__
M4.B3X?__68OX6>B;X___A<!T*(7V="16Z+8&``"%P%ET&6@@0T``5_\5B$!`
M`%D[QUEU!U;H!````%E?7L.![!P!``!3BYPD)`$``%97A=L/A"8!``!3Z'<&
M``"%P%D/A!<!``!3Z&@&``"+\('&`@$``.BO!0``4.C!!0``BSA965;HGP4`
M`%#HL04``%G_,/\7B_!3:(Q#0`!6_Q6D0$``C40D)%!6_Q5(0$``@\0<@_C_
MB40D#`^$O@```%6++4Q`0`#K!XN<)#`!``"+/8A`0`"-1"0H:%!!0`!0_]=9
MA<!9C40D*%!U$E-HA$-``%;_%:1`0`"#Q!#K#VB`0T``5O\5I$!``(/$#+M\
M0T``4U;_UXOX687_670>4U?HJ04``%F%P%ET'VAX0T``5^B8!0``687`670.
M]D0D%!!T1%;H]O[__UF-1"044/]T)!3_%5!`0`!9A<!9#X1E_____W0D$/\5
M5$!``/^T)#0!``#_%:!`0`!965U?7EN!Q!P!``##C40D*%#_%0A`0`"+^#/;
M5O_5A<!9=*R+PT.#^`I]I(7_=.Q7_Q4,0$``Z^-1@V0D``!35E?H9P0``%#H
MNP0``&H!6X@8QP0D7$)``.B5W?__A<!9=`N`.#%U!H!X`0!T!>A=X/__:@I3
M:/A#0`#H+@0``%#H?`0``(/$$(7`#X2=````BP`Y'4BT0`!5B_.+0""+>!!^
M7KT```0`C4;_:@!05^CY`P``4.A!!```@\00A<!T0(L`BT@((\T[S74&BP"+
M`.L.4.C5`P``4.@7!```65E0H4RT0`#_-+#H900``%F%P%EU#?]$)!!&.S5(
MM$``?*>A2+1``%V-2/\Y3"0,=1T[PXOS?A=7Z)$#``!0Z,T#``!&63LU2+1`
M`%E\Z6H$4VCT0T``Z',#``!0Z,$#``"+\(/$$(7V=#6+!FCH0T``BT`@_S#H
M4P,``%#HB0,``(L&@\0,BT`@BP#V0`E`=`Y0Z#<#``!0Z&<#``!966H$4VCD
M0T``Z"(#``!0Z'`#``"+\(/$$(7V=')HB$%``.A.W/__A<!9=`-0ZTOH@-K_
M_XOXA?]T.8L&5XM`(/\PZ.D"``!0Z!\#``#HW@(``%#H\`(``(LP@\005^C-
M`@``4.C?`@``6?\P_U8(65GK'*%,M$``_S"+!HM`(/\PZ*H"``!0Z.`"``"#
MQ`SHG`(``%#H\`(``(`@`.B.`@``4.BX`@``@R``:)A!0`#HP-O__X/$#*-$
ML$``A<!U$?\U3+1``.@DX?__6:-$L$``Z%D"``!0Z'T"``"+,,<$).T!``#_
M-42P0`#H/P(``%#H8P(``%G_,/\6@\0,A<!?7EMT)8/X$70@@_C_=!M0H4RT
M0`#_-42P0`#_,&B40T``Z"P"``"#Q!!9PU6+[(U%#%90C44(4/\5K$!``&H`
MZ(`"``"#Q`R`.`!U3.AM`@``A<"C0+!``'4CZ,\!``!0Z.<!``"+,%EJ`>B_
M`0``4.C7`0``6?\P_U8(65G_-4"P0`#H,`(``.BA`0``4.@?`@``@R``65GH
MD0$``%#H"0(``(`(`NB#`0``4.C[`0``@`@!BT4(@\`%63W___\_678+:`A$
M0`#HA0$``%F+10B-!(44````4.C(`0``6:-,M$``BTT,:@&+"8D(H4RT0`#'
M0`0$1$``H4RT0`#'0`@T1$``H4RT0`#'!4BT0``#````QT`,`$1``/\%2+1`
M`%@Y10A^'HL-2+1``(M5#(LU3+1```/(BQ2"0(E4COP[10A\XJ%(M$``BTT(
M`\&+#4RT0`!J`(-D@?P`H4BT0`"+30C_-4RT0`"-1`C_4&A9.$``_S5`L$``
MZ"$!``"+\(/$%(7V=0[_-4"P0`#H!P$``%F+\/\U0+!``.CS````QP0D4$)`
M`.C&V?__A<!9=22A1+!``(7`=11HF$%``.BNV?__A<!9HT2P0`!T!U#H)OK_
M_UG_-4"P0`#HK0```%G_%=A`0`"+QEY=P^@\````4.B<U___6;B00D``4%!H
M)31``&@<1$``Z!\```!0Z!,```"#Q!!0Z!````!0Z$8```"#Q`S#_R4<04``
M_R4804``_R4404``_R4004``_R4,04``_R4(04``_R4$04``_R4`04``_R7\
M0$``_R7X0$``_R7T0$``_R7P0$``_R7L0$``_R7H0$``_R7D0$``_R7@0$``
M_R7<0$``_R740$``_R700$``_R7,0$``_R7(0$``_R7$0$``_R7`0$``_R6\
M0$``_R6X0$``_R6T0$``_R6P0$``S,S,S,S,S,S,S/\EE$!``/\EC$!``,S,
MS,Q1/0`0``"-3"0(<A2!Z0`0```M`!```(4!/0`0``!S["O(B\2%`8OABPB+
M0`10P\S_)6!`0`#_)5Q`0`!5B^QJ_VC@H$``:,`Z0`!DH0````!09(DE````
M`(/L(%-65XEEZ(-E_`!J`?\56$!``%F##62T0`#_@PUHM$``__\5&$!``(L-
M8+1``(D(_Q4<0$``BPU<M$``B0BA($!``(L`HVRT0`#HP````(,],+!```!U
M#&@>$$``_Q4D0$``6>B4````:`RP0`!H"+!``.A_````H5BT0`")1=B-1=A0
M_S54M$``C47@4(U%U%"-1>10_Q4L0$``:`2P0`!H`+!``.A,````_Q4P0$``
MBTW@B0C_=>#_==3_=>3H*/S__X/$,(E%W%#_%31`0`"+1>R+"(L)B4W04%'H
M#P```%E9PXMEZ/]UT/\5/$!``/\E.$!``/\E*$!``&@```,`:````0#H#P``
M`%E9P\/,S,S,S/\EF$!``/\EG$!`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````-*D````````L*0``**D``",I````````'JF``!JI@``6J8``$:F```Z
MI@``*J8``!JF```2I@``!*8``/RE``#DI0``VJ4``,RE``#"I0``MJ4``*BE
M``"(I@``E*4``(JE``!ZI0``;J4``&2E``!:I0``4*4``$:E```\I0``,J4`
M`"*E```8I0``#J4```2E``#ZI```FJ8``*ZF``">I0``\*0```````!NI```
M6*0``$JD```XI```&*0```"D``#JHP``W*,``-"C``#`HP``M*,``**C``".
MHP``?*,``&RC``!8HP``2*,``#BC```JHP``%J,```:C``#NH@``W*(``,RB
M``"\H@``J*(``):B``""H@``=*(`````````````````````````````SSK6
M20`````"````.P``````````X```.P```%P```!$>6YA3&]A9&5R.CIB;V]T
M7T1Y;F%,;V%D97(`<&5R;'AS:2YC````)7,E<R5S```N````4$%27U!23T=.
M04U%`````%!!4E]414U0`````#$```!005)?0TQ%04X]``!#3$5!3@```%!!
M4E]'3$]"04Q?0TQ%04X`````4$%27T=,3T)!3%]414U0`%!!4E]435!$25(`
M`%!!4E]'3$]"04Q?5$U01$E2````4$%27T=,3T)!3%]$14)51P````!005)?
M05)'5E\P``!005)?05)'0P````!005)?0T%#2$4```!005)?1$5"54<```!0
M05)?0TQ%04X```!005)?4U!!5TY%1`!005)?24Y)5$E!3$E:140`7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("```````````$193$1?3$E"4D%2
M65]0051(````4$%42`````!,24)205)97U!!5$@`````3$E"4$%42`!,1%],
M24)205)97U!!5$@`)7,E<W1E;7`M)74M)74E<P`````E<R5S=&5M<"TE=25S
M````)3`R>``````E<R5S8V%C:&4M)7,E<P``)7,E<R5S)7,`````<&%R+0``
M```E<UQT96UP`%=I;D1I<@``4UE35$5-``!54T523D%-10````!54T52````
M`%1-4`!414U0`````%1%35!$25(`5$U01$E2``!#.EQ414U0`%PN+@!<+@``
M)7,``"5S7"5S````)7-<*BXJ```E<SH@8W)E871I;VX@;V8@<')I=F%T92!T
M96UP;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I
M=&@@)6DN"@```#````!P97)L+F5X90`````8````05)'5@`````M+0``+64`
M`'!A;FEC.B!M96UO<GD@=W)A<```26YT97)N86QS.CI005(Z.D)/3U0`````
M(R$O=7-R+V)I;B]P97)L#0H-"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PT*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`T*#0IP86-K86=E(%]?<&%R7W!L.PT*#0HC("TM+2!4
M:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL
M92!T:6UE("TM+0T*(R!U<V4@<W1R:6-T.PT*#0HC;&EN92`Q-3D-"@T*;7D@
M*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D[#0I%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2![#0H@("`@<F5Q=6ER92!&:6QE.CI496UP.PT*
M("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64[#0H@("`@<F5Q=6ER92!&:6QE
M.CI3<&5C.PT*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D<&%R7W1E;7`I.PT*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@
M:6X@(B1P87)?=&5M<")]*3L-"B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L-
M"B`@("!R;61I<B`D<&%R7W1E;7`[#0H@("`@(R!$;VXG="!R96UO=F4@=&]P
M9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P
M<PT*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@T*#0H@("`@:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![#0H@("`@("`@
M(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A
M<GD@9&ER96-T;W)Y+B`@5&AI<PT*("`@("`@("`C('1Y<&EC86QL>2!H87!P
M96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R
M960-"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@
M87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD#0H@("`@("`@
M(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I
M;B!U<V4@8GD@=&AI<R!P<F]C97-S+@T*("`@("`@("`C($1O;B=T(&1O(&%N
M>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@
M=VEL;`T*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@
M=7`N#0H-"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`T*("`@
M("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP-"B`@("`@("`@("`@
M($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P-"B`@
M("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L#0H@("`@("`@("`@("!53DQ)
M3DL@/3X@,"P-"B`@("`@("`@*3L-"@T*("`@("`@("!P<FEN="`D=&UP("(C
M(2]B:6XO<V@-"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O#0H@("!R
M;2`M<F8@)R1P87)?=&5M<"<-"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@T*("`@("`@(&)R96%K#0H@("!F:0T*("`@<VQE97`@,0T*("`@
M>#U@97AP<B!<)'@@*R`Q8`T*9&]N90T*<FT@)R(@+B`D=&UP+3YF:6QE;F%M
M92`N("(G#0HB.PT*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L-"B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<[#0H@("`@("`@(&-L;W-E("1T;7`[#0H@("`@
M("`@('-Y<W1E;2@D8VUD*3L-"B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D-"B`@("`@
M("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L-"B`@("!]#0I]('T-"@T*0D5'
M24X@>PT*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F
M26YT97)N86QS.CI005(Z.D)/3U0[#0H-"B`@("!E=F%L('L-"@T*7W!A<E]I
M;FET7V5N=B@I.PT*#0II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD
M("1%3E9[4$%27T%21U9?,'T@*2![#0H@("`@0$%21U8@/2!M87`@)$5.5GLB
M4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L-"B`@
M("`D,"`]("1%3E9[4$%27T%21U9?,'T[#0I]#0IE;'-E('L-"B`@("!F;W(@
M*&ME>7,@)45.5BD@>PT*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY0
M05)?05)'5E\O.PT*("`@('T-"GT-"@T*;7D@)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L-"@T*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0
M051(#0IM>2`E0V]N9FEG(#T@*`T*("`@('!A=&A?<V5P("`@(#T^("@D7D\@
M/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`T*("`@(%]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL#0H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@
M/R`G7%PG(#H@)R\G*2P-"BD[#0H-"E]S971?<')O9VYA;64H*3L-"E]S971?
M<&%R7W1E;7`H*3L-"@T*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X
M=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PT*;7D@*"1S=&%R=%]P;W,L
M("1D871A7W!O<RD[#0I[#0H@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S
M=6(@>WT[#0H-"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F
M(&1A=&$@<V5C=&EO;B![>WL-"B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA
M;64@;W(@;&%S=#L-"B`@("!B:6YM;V1E*%]&2"D[#0H-"B`@("!M>2`D8G5F
M.PT*("`@('-E96L@7T9(+"`M."P@,CL-"B`@("!R96%D(%]&2"P@)&)U9BP@
M.#L-"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL-"@T*
M("`@('-E96L@7T9(+"`M,3(L(#([#0H@("`@<F5A9"!?1D@L("1B=68L(#0[
M#0H@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PT*
M("`@(')E860@7T9(+"`D8G5F+"`T.PT*#0H@("`@)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0[#0H@("`@(R!]?7T-"@T*("`@(",@17AT<F%C=&EN9R!E
M86-H(&9I;&4@:6YT;R!M96UO<GD@>WM[#0H@("`@;7D@)7)E<75I<F5?;&ES
M=#L-"B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L-"B`@("`@("`@<F5A
M9"!?1D@L("1B=68L(#0[#0H@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L-"@T*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F
M.PT*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B
M+BXN*2D[#0H@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH
M6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[#0H@("`@("`@(&UY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L-"@T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L-"B`@("`@("`@
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PT*#0H@("`@("`@
M(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PT*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@
M/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD[#0H@("`@("`@("`@("!I9B`H)&]U
M="D@>PT*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[#0H@("`@("`@
M("`@("`@("`@<')I;G0@)&]U="`D8G5F.PT*("`@("`@("`@("`@("`@(&-L
M;W-E("1O=70[#0H@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N
M86UE.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PT*("`@("`@("`@
M("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN
M86UE.PT*("`@("`@("!]#0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L-
M"B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I
M#0H@("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO
M)&)A<V5N86UE)&5X="([#0H@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L-"B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D
M9FEL96YA;64@;W(@9&EE("0A.PT*("`@("`@("`@("`@8FEN;6]D92@D;W5T
M*3L-"B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL-"B`@("`@("`@("`@
M(&-L;W-E("1O=70[#0H@("`@("`@('T-"B`@("`@("`@96QS92![#0H@("`@
M("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0T*("`@("`@("`@
M("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![#0H@
M("`@("`@("`@("`@("`@8G5F(#T^("1B=68L#0H@("`@("`@("`@("`@("`@
M8W)C(#T^("1C<F,L#0H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA
M;64L#0H@("`@("`@("`@("!].PT*("`@("`@("!]#0H@("`@("`@(')E860@
M7T9(+"`D8G5F+"`T.PT*("`@('T-"B`@("`C('U]?0T*#0H@("`@;&]C86P@
M0$E.0R`]("AS=6(@>PT*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\[#0H-"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D
M=6QE.PT*#0H@("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5]('Q\(&1O('L-"B`@("`@("`@("`@(&UY("1K97D[
M#0H@("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L-
M"B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL-
M"B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I
M9B!D969I;F5D*"1K97DI.PT*("`@("`@("!](&]R(')E='5R;CL-"@T*("`@
M("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U
M;&4B.PT*#0H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2![#0H@("`@("`@("`@("!M>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PT*("`@("`@("`@("`@
M8FEN;6]D92@D9F@I.PT*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M
M92T^>V)U9GT[#0H@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D[#0H@("`@
M("`@("`@("!R971U<FX@)&9H.PT*("`@("`@("!]#0H@("`@("`@(&5L<V4@
M>PT*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G
M+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D[#0H@("`@("`@("`@("!I9B`H)&]U
M="D@>PT*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[#0H@("`@("`@
M("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PT*("`@("`@
M("`@("`@("`@(&-L;W-E("1O=70[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$[#0H@("`@
M("`@("`@("!B:6YM;V1E*"1F:"D[#0H@("`@("`@("`@("!R971U<FX@)&9H
M.PT*("`@("`@("!]#0H-"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B([#0H@("`@?2P@0$E.0RD[
M#0H-"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PT*#0H@
M("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PT*("`@
M(')E<75I<F4@6%-,;V%D97([#0H@("`@<F5Q=6ER92!005(Z.DAE879Y.PT*
M("`@(')E<75I<F4@0V%R<#HZ2&5A=GD[#0H@("`@<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD[#0H@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PT*#0H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L
M97,@9G)O;2!W:71H:6X-"B`@("!R97%U:7)E($E/.CI&:6QE.PT*#0H@("`@
M(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN#0H@("`@=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L-"B`@
M("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL-"B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![#0H@("`@("`@("`@("`C
M(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PT*
M("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2![#0H@
M("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!E;'-E('L-"B`@("`@("`@("`@("`@("`C(%-K
M:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z#0H@("`@
M("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L-
M"B`@("!]#0H-"B`@("`C('U]?0T*#0H@("`@;&%S="!U;FQE<W,@)&)U9B!E
M<2`B4$M<,#`S7#`P-"([#0H@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PT*?0T*(R!]?7T-"@T*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PT*
M;7D@0'!A<E]A<F=S.PT*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PT*#0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)5
M1WT[#0H-"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D
M(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PT*:68@*"$D<W1A
M<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI
M9G0I*2![#0H@("`@;7D@)61I<W1?8VUD(#T@<7<H#0H@("`@("`@('`@("!B
M;&EB7W1O7W!A<@T*("`@("`@("!I("`@:6YS=&%L;%]P87(-"B`@("`@("`@
M=2`@('5N:6YS=&%L;%]P87(-"B`@("`@("`@<R`@('-I9VY?<&%R#0H@("`@
M("`@('8@("!V97)I9GE?<&%R#0H@("`@*3L-"@T*("`@(&UY($!A9&1?=&]?
M:6YC.PT*("`@('=H:6QE("A`05)'5BD@>PT*("`@("`@("`D05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PT*#0H@("`@
M("`@(&EF("@D,2!E<2`G22<I('L-"B`@("`@("`@("`@('!U<V@@0&%D9%]T
M;U]I;F,L("0R.PT*("`@("`@("!]#0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M32<I('L-"B`@("`@("`@("`@(&5V86P@(G5S92`D,B([#0H@("`@("`@('T-
M"B`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PT*("`@("`@("`@("`@=6YS
M:&EF="!`<&%R7V%R9W,L("0R.PT*("`@("`@("!]#0H@("`@("`@(&5L<VEF
M("@D,2!E<2`G3R<I('L-"B`@("`@("`@("`@("1O=70@/2`D,CL-"B`@("`@
M("`@?0T*("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2![#0H@("`@("`@("`@
M("`D8G5N9&QE(#T@)W-I=&4G.PT*("`@("`@("!]#0H@("`@("`@(&5L<VEF
M("@D,2!E<2`G0B<I('L-"B`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL-
M"B`@("`@("`@?0T*("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2![#0H@("`@
M("`@("`@("`D<75I970@/2`Q.PT*("`@("`@("!]#0H@("`@("`@(&5L<VEF
M("@D,2!E<2`G3"<I('L-"B`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([#0H@("`@
M("`@('T-"B`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PT*("`@("`@("`@
M("`@)&-A8VAE7VYA;64@/2`D,CL-"B`@("`@("`@?0T*#0H@("`@("`@('-H
M:69T*$!!4D=6*3L-"@T*("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L-"B`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PT*("`@("`@("`@("`@:6YI=%]I;F,H*3L-"B`@("`@("`@("`@(')E<75I
M<F4@4$%2.CI$:7-T.PT*("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8[#0H@("`@("`@("`@("`F>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PT*("`@("`@("`@("`@97AI=#L-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I
M;F,[#0I]#0H-"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0T*
M#0HC('U]?0T*#0HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM[#0II
M9B`H)&]U="D@>PT*("`@('L-"B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP
M;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL-"B`@("`@("`@
M<F5Q=6ER92!)3SHZ1FEL93L-"B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI:
M:7`[#0H@("`@?0T*#0H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L-"B`@
M("!M>2`D>FEP.PT*#0H-"B`@("!I9B`H9&5F:6YE9"`D<&%R*2![#0H@("`@
M("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN
M9"`G)'!A<B<Z("0A(CL-"B`@("`@("`@8FEN;6]D92@D9F@I.PT*("`@("`@
M("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PT*#0H@("`@("`@("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL-"B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0T*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B
M.PT*("`@('T-"@T*#0H@("`@;7D@)65N=B`](&1O('L-"B`@("`@("`@:68@
M*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL
M)RDI('L-"B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PT*
M("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,[#0H@("`@("`@("`@
M("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<[#0H@("`@("`@('T-
M"B`@("!].PT*#0H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@
M>WM[#0H@("`@;&]C86P@)"\@/2!<-#L-"@T*("`@(&EF("AD969I;F5D("1P
M87(I('L-"B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL-"B`@("`@("`@8FEN;6]D92A005(I.PT*("`@("`@("!D:64@
M(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<
M,#`S7#`P-"([#0H@("`@?0T*#0H@("`@0W)E871E4&%T:"@D;W5T*2`[#0H@
M("`@#0H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@-"B`@("`@("`@)&]U
M="P-"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/
M7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P-"B`@("`@("`@,#<W
M-RP-"B`@("`I(&]R(&1I92`D(3L-"B`@("!B:6YM;V1E*"1F:"D[#0H-"B`@
M("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD
M968[#0H@("`@<V5E:R!?1D@L(#`L(#`[#0H@("`@;7D@)&QO861E<B`]('-C
M86QA<B`\7T9(/CL-"B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L-"B`@("`@("`@<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[#0H@("`@("`@(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I#0H@("`@?0T*
M("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L-"B`@("`@
M("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L-"B`@("`@("`@)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[#0H@("`@("`@(&UY
M("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL-"B`@
M("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL-
M"B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PT*("`@("`@("`@
M("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T
M:"@D<V5T*2DI#0H@("`@("`@('UE9SL-"B`@("!]#0H@("`@)&9H+3YP<FEN
M="@D;&]A9&5R*3L-"B`@("`D+R`]('5N9&5F.PT*("`@(",@?7U]#0H-"B`@
M("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL-"B`@("!I9B`H)&)U;F1L
M92D@>PT*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD[#0H@("`@("`@(%!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L-"B`@("`@("`@:6YI=%]I
M;F,H*3L-"@T*("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L-"@T*("`@("`@
M("!M>2!`:6YC(#T@<V]R="![#0H@("`@("`@("`@("!L96YG=&@H)&(I(#P]
M/B!L96YG=&@H)&$I#0H@("`@("`@('T@9W)E<"![#0H@("`@("`@("`@("`A
M+T)31%!!3B\-"B`@("`@("`@?2!G<F5P('L-"B`@("`@("`@("`@("@D8G5N
M9&QE(&YE("=S:71E)RD@;W(-"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD#0H@("`@("`@("`@("`@)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L-"B`@("`@("`@?2!`24Y#
M.PT*#0H@("`@("`@(&EF("@D0V]N9FEG>U]D96QI;7T@97$@)UQ<)RD@>R!S
M>UQ<?7LO?6<@9F]R($!I;F,@?0T*#0H@("`@("`@(",@1FEL92!E>&ES=',@
M=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@T*("`@("`@("`C($9U;FYY
M+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]2
M87<O6FQI8B]A=71O<W!L:70N:7@N#0H@("`@("`@(",@5&AI<R!I<R!A(&)A
M;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N
M#0H@("`@("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A
M:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`T*("`@("`@
M("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N#0H@("`@("`@(&UY("5F:6QE<SL-
M"B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK
M*R!F;W(@:V5Y<R`E.CH[#0H@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L
M=65S("5)3D,[#0H-"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T[#0H@("`@("`@(&UY("5W<FET=&5N.PT*#0H@("`@
M("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L-"B`@("`@("`@("`@
M(&UY("@D;F%M92P@)&9I;&4I.PT*#0H@("`@("`@("`@("!F;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L-"B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D9FEL92`]("1?.PT*("`@("`@("`@("`@("`@("`@("!L87-T.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH
M7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2![#0H@("`@("`@("`@("`@("`@
M("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD[#0H@("`@("`@("`@("`@
M("`@("`@(&QA<W0[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD,7TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&QA<W0[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D[#0H@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*#0H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE
M(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL[#0H@("`@("`@("`@("!N97AT
M(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D
M+SL-"B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L#0H@("`@("`@("`@("`@
M("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z
M("1F:6QE+`T*("`@("`@("`@("`@("`@('%Q*"(N+BXI#0H@("`@("`@("`@
M("`I.PT*#0H@("`@("`@("`@("!M>2`D8V]N=&5N=#L-"B`@("`@("`@("`@
M(&EF("AR968H)&9I;&4I*2![#0H@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/2`D9FEL92T^>V)U9GT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!E
M;'-E('L-"B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@
M;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2([#0H@("`@("`@("`@("`@
M("`@8FEN;6]D92A&24Q%*3L-"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]
M(#Q&24Q%/CL-"B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PT*#0H@("`@
M("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4I#0H@("`@("`@("`@("`@("`@("`@(&EF("$D
M14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L
M*20O:3L-"@T*("`@("`@("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO861E
M<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N=FER;VYM96YT#0H@("`@("`@("`@
M("`@("`@)&-O;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G
M;W1O(')E=')Y.R\-"B`@("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I
M(&5Q(&QC*")84TQO861E<BYP;2(I.PT*("`@("`@("`@("`@?0T*#0H@("`@
M("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PT*("`@("`@
M("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PT*("`@("`@("`@("`@)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L-"B`@("`@("`@
M("`@("1F:"T^<')I;G0H<W!R:6YT9B@-"B`@("`@("`@("`@("`@("`B)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64-"B`@("`@("`@("`@("DI.PT*("`@("`@("`@("`@)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PT*("`@("`@("`@("`@
M)&9H+3YP<FEN="@D8V]N=&5N="D[#0H@("`@("`@('T-"B`@("!]#0H@("`@
M(R!]?7T-"@T*("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I
M8R!S=')I;F=S('M[>PT*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@:68@)'II<#L-"@T*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H
M95]N86UE+"`P+"`T,#L-"B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L-"B`@("`@("`@;7D@)&-T>"`]
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W
M*#$I('T-"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0T*("`@("`@("`@("`@?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L-
M"@T*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(
M02`U+C,X(&%N9"`U+C,Y#0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PT*("`@("`@("!I
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2![#0H@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B
M(BD@:68@*"1C='@I.PT*("`@("`@("!]#0H@("`@("`@(&5L<V4@>PT*("`@
M("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@
M>PT*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L-"B`@("`@("`@("`@
M("`@("`D8W1X+3YA9&1F:6QE*"1F:"D[#0H@("`@("`@("`@("`@("`@8VQO
M<V4H)&9H*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@
M("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M93L-"B`@("!]#0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE
M;F=T:"`D8V%C:&5?;F%M92D[#0H@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%
M(CL-"B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L-"B`@("`D9F@M/G!R
M:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L-
M"B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD[#0H@("`@)&9H+3YC;&]S
M93L-"B`@("!C:&UO9"`P-S4U+"`D;W5T.PT*("`@(",@?7U]#0H-"B`@("!E
M>&ET.PT*?0T*(R!]?7T-"@T*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!
M4B!F:6QE(&-A8VAE('M[>PT*>PT*("`@(&QA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL-"@T*("`@(%]F:7A?<')O9VYA;64H*3L-"@T*("`@(",@
M3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI
M8D-A8VAE('M[>PT*("`@(')E<75I<F4@4$%2.PT*("`@(%!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L-"@T*#0H@("`@>PT*("`@("`@("`C;&]C
M86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN
M,S(G.PT*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0[#0H@("`@("`@(')E
M<75I<F4@07)C:&EV93HZ6FEP.PT*("`@('T-"B`@("!M>2`D>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<[#0H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL-
M"B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"([#0H@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@
M)$`B.PT*#0H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L-"B`@("`D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L-"@T*("`@("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT[#0H@("`@;W5T<RAQ<2A<)$5.5GM005)?
M5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D[#0H-"B`@("!I9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$-"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M
M8F5R<R`I('L-"B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD[#0H@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L-"B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PT*("`@("`@("`@("`@("`@(%X-"B`@("`@("`@("`@("`@
M("`O/W-H;&EB+PT*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I
M9WMV97)S:6]N?2\I/PT*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\-"B`@("`@("`@("`@("`@("`H6UXO72LI#0H@
M("`@("`@("`@("`@("`@)`T*("`@("`@("`@("`@?7@[#0H@("`@("`@("`@
M("!M>2`D97AT<F%C=%]N86UE(#T@)#$[#0H@("`@("`@("`@("!M>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D[#0H@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PT*
M("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&]U=',H
M<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I
M*3L-"B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D[#0H@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@('T-"B`@("`C('U]?0T*?0T*(R!]?7T-"@T*(R!)
M9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PT*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![#0H@("`@9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8[#0I5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!=#0H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP
M87(-"BX-"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D
M,"`]('-H:69T*$!!4D=6*3L-"GT-"B,@?7U]#0H-"G-U8B!#<F5A=&50871H
M('L-"B`@("!M>2`H)&YA;64I(#T@0%\[#0H@("`@#0H@("`@<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L-"B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D[#0H@("`@#0H@("`@<F5Q=6ER92!&:6QE.CI0871H.PT*("`@(`T*("`@
M($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R#0I]#0H-"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PT*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?
M(&EF("1>3R!N92`G35-7:6XS,B<[#0H-"B`@("!R97%U:7)E(&QI8CL-"B`@
M("!R97%U:7)E($1Y;F%,;V%D97([#0H@("`@<F5Q=6ER92!I;G1E9V5R.PT*
M("`@(')E<75I<F4@<W1R:6-T.PT*("`@(')E<75I<F4@=V%R;FEN9W,[#0H@
M("`@<F5Q=6ER92!V87)S.PT*("`@(')E<75I<F4@0V%R<#L-"B`@("!R97%U
M:7)E($-A<G`Z.DAE879Y.PT*("`@(')E<75I<F4@17)R;F\[#0H@("`@<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD[#0H@("`@<F5Q=6ER92!%>'!O<G1E<CL-
M"B`@("!R97%U:7)E($9C;G1L.PT*("`@(')E<75I<F4@1FEL93HZ5&5M<#L-
M"B`@("!R97%U:7)E($9I;&4Z.E-P96,[#0H@("`@<F5Q=6ER92!84TQO861E
M<CL-"B`@("!R97%U:7)E($-O;F9I9SL-"B`@("!R97%U:7)E($E/.CI(86YD
M;&4[#0H@("`@<F5Q=6ER92!)3SHZ1FEL93L-"B`@("!R97%U:7)E($-O;7!R
M97-S.CI:;&EB.PT*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PT*("`@(')E
M<75I<F4@4$%2.PT*("`@(')E<75I<F4@4$%2.CI(96%V>3L-"B`@("!R97%U
M:7)E(%!!4CHZ1&ES=#L-"B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L-"B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L-"B`@("!E=F%L('L@
M<F5Q=6ER92!7:6XS,B!].PT*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PT*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PT*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#
M87!T=7)E('T[#0I]#0H-"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@
M87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC#0HC(%1H:7,@8V]D92!A;'-O
M(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A
M#0IS=6(@7W-E=%]P87)?=&5M<"![#0H@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PT*("`@
M("`@("`D<&%R7W1E;7`@/2`D,3L-"B`@("`@("`@<F5T=7)N.PT*("`@('T-
M"@T*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`T*("`@("`@("`H;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P-"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I#0H@("`@*2![#0H@
M("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H
M(&%N9"`M=R`D<&%T:#L-"B`@("`@("`@;7D@)'5S97)N86UE.PT*("`@("`@
M("!M>2`D<'=U:60[#0H@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H
M97)E.@T*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT[#0H-"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L-"B`@("`@("`@("`@("1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PT*("`@("`@("!]#0H@("`@("`@(&5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PT*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W
M=6ED.PT*("`@("`@("!]#0H@("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G
M4UE35$5-)SL-"B`@("`@("`@?0T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<
M5R]?+V<[#0H-"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG
M>U]D96QI;7UP87(M)'5S97)N86UE(CL-"B`@("`@("`@;6MD:7(@)'-T;7!D
M:7(L(#`W-34[#0H@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PT*("`@("`@("`@
M("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D[#0H@("`@("`@("`@
M("!S965K("1F:"P@+3$X+"`R.PT*("`@("`@("`@("`@<WES<F5A9"`D9F@L
M(&UY("1B=68L(#8[#0H@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(
M12(I('L-"B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PT*("`@
M("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L-"B`@("`@("`@
M("`@("`@("`D8G5F(#U^(',O7#`O+V<[#0H@("`@("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@96QS92![#0H@("`@("`@("`@("`@
M("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E
M<W0Z.E-(02T^;F5W*#$I('T-"B`@("`@("`@("`@("`@("`@("`@?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]
M#0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T[#0H-"B`@("`@("`@("`@("`@
M("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N
M9"`U+C,Y#0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A
M;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`[#0H@("`@("`@("`@
M("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PT*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA
M9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE
M(BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H-"B`@("`@("`@
M("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N
M("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@8VQO<V4H)&9H*3L-"B`@("`@("`@?0T*
M("`@("`@("!E;'-E('L-"B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`]
M(#$[#0H@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M=&5M<"TD)"([#0H@("`@("`@('T-"@T*("`@("`@("`D14Y6>U!!4E]414U0
M?2`]("1S=&UP9&ER.PT*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L-
M"B`@("`@("`@;&%S=#L-"B`@("!]#0H-"B`@("`D<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PT*?0T*#0IS=6(@7W1E;7!F:6QE('L-"B`@("!M>2`H)&5X="P@)&-R8RD@
M/2!`7SL-"B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PT*#0H@("`@)&9I;&5N
M86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="([#0H-"B`@("!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2![#0H@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@
M)&9I;&5N86UE.PT*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64[
M#0H@("`@?0T*("`@(&5L<V4@>PT*("`@("`@("!R971U<FX@*'5N9&5F+"`D
M9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PT*("`@('T-"@T*("`@(&]P
M96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$[#0H@("`@8FEN;6]D
M92@D9F@I.PT*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D[#0I]#0H-"B,@
M<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R
M;V=N86UE#0IS=6(@7W-E=%]P<F]G;F%M92![#0H@("`@:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2![#0H@("`@("`@("1P<F]G;F%M92`]("0Q.PT*("`@('T-"@T*
M("`@("1P<F]G;F%M92!\?#T@)#`[#0H-"B`@("!I9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L-"B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PT*("`@('T-
M"@T*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2![#0H@("`@("`@(&EF("AO
M<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L-"B`@("`@("`@("`@(')E
M='5R;B!I9B`M<R`D9F@[#0H@("`@("`@('T-"B`@("`@("`@:68@*"US("(D
M<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PT*("`@("`@("`@("`@)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T[#0H@("`@("`@("`@("!R971U<FX[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![#0H@("`@
M("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PT*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG
M>U]D96QI;7U<120O+SL-"B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D-
M"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2([#0H@("`@("`@("@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D-"B`@("`@("`@
M("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL-"B`@
M("!]#0I]#0H-"G-U8B!?9FEX7W!R;V=N86UE('L-"B`@("`D,"`]("1P<F]G
M;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PT*("`@(&EF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2![#0H@("`@("`@("1P
M<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL-"B`@("!]
M#0H-"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PT*("`@(&UY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0T*("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L-"B`@("!C:&]M<"@D<'=D
M*3L-"B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E
M;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL-"@T*("`@("1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L-"GT-"@T*<W5B(%]P87)?:6YI=%]E
M;G8@>PT*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L-"B`@("`@("`@<F5T=7)N.PT*("`@('T@96QS92![#0H@("`@("`@("1%
M3E9[4$%27TE.251)04Q)6D5$?2`](#([#0H@("`@?0T*#0H@("`@9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%2
M1T,@05)'5E\P("D@*2![#0H@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD
M7WT[#0H@("`@?0T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L-"B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?3L-"B`@("!]#0H-"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@(CL-"@T*("`@(&EF("@D14Y6>U!!4E]4
M14U0?2D@>PT*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PT*("`@
M('T-"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]
M*2![#0H@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q
M,B`K(&QE;F=T:"@B0TQ%04XB*2D[#0H@("`@("`@("1%3E9[4$%27T-,14%.
M?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[#0H@("`@
M?0T*?0T*#0IS=6(@;W5T<R![#0H@("`@<F5T=7)N(&EF("1Q=6EE=#L-"B`@
M("!I9B`H)&QO9V9H*2![#0H@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B([
M#0H@("`@?0T*("`@(&5L<V4@>PT*("`@("`@("!P<FEN="`B0%]<;B([#0H@
M("`@?0T*?0T*#0IS=6(@:6YI=%]I;F,@>PT*("`@(')E<75I<F4@0V]N9FEG
M.PT*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H#0H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP#0H@("`@("`@('9E;F1O<F%R8VAE
M>'`@=F5N9&]R;&EB97AP#0H@("`@*3L-"GT-"@T*(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C#0HC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E
M>&5C=71I;VX-"@T*<&%C:V%G92!M86EN.PT*#0IR97%U:7)E(%!!4CL-"G5N
M<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PT*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L-"@T*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C
M<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN
M*0T*("`@('5N;&5S<R`M92`D<')O9VYA;64[#0H-"F1O("1P<F]G;F%M93L-
M"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD[#0ID:64@)$`@:68@)$`[#0H-"GT[#0H-"B0Z.E]?15)23U(@/2`D0"!I
M9B`D0#L-"GT-"@T*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PT*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL-"@T*,3L-"@T*(VQI;F4@,3`P,@T*#0I?7T5.1%]?#0H`<&%R
M+G!L````````_____WPZ0`"0.D``_*$`````````````@*0``*Q```!8H0``
M``````````#$I```"$```%"A`````````````.*D````0```:*$`````````
M````\*4``!A``````````````````````````````-*D````````L*0``**D
M``",I````````'JF``!JI@``6J8``$:F```ZI@``*J8``!JF```2I@``!*8`
M`/RE``#DI0``VJ4``,RE``#"I0``MJ4``*BE``"(I@``E*4``(JE``!ZI0``
M;J4``&2E``!:I0``4*4``$:E```\I0``,J4``"*E```8I0``#J4```2E``#Z
MI```FJ8``*ZF``">I0``\*0```````!NI```6*0``$JD```XI```&*0```"D
M``#JHP``W*,``-"C``#`HP``M*,``**C``".HP``?*,``&RC``!8HP``2*,`
M`#BC```JHP``%J,```:C``#NH@``W*(``,RB``"\H@``J*(``):B``""H@``
M=*(```````#%`U!E<FQ?;F5W6%,``/("4&5R;%]G971?8V]N=&5X=```\`1B
M;V]T7T1Y;F%,;V%D97(`7`)097)L7U1S=&%T8G5F7W!T<@"R`%!E<FQ?24Q)
M3U]P='(`M0!097)L7TE-96U?<'1R`+D`4&5R;%])4')O8U]P='(``+H"4&5R
M;%]C<F]A:U]N;V-O;G1E>'0``+``4&5R;%])1&ER7W!T<@#/`%!E<FQ?26-O
M;7!C=E]P='(``'\#4&5R;%]M9U]S970`D`1097)L7W-V7W-E='!V`'8"4&5R
M;%]A=E]S:&EF=`!#!%!E<FQ?<W9?,G!V7VYO;&5N`'`"4&5R;%]A=E]F971C
M:``1`U!E<FQ?9W9?9F5T8VAP=@!@`E!E<FQ?5'1A:6YT961?<'1R`.X$4&5R
M;%]W:6XS,E]T97)M`/D$<&5R;%]F<F5E`/@$<&5R;%]D97-T<G5C=`#\!'!E
M<FQ?<G5N``#[!'!E<FQ?<&%R<V4``/L#4&5R;%]S869E<WES;6%L;&]C``#P
M`%!E<FQ?265X:71?9FQA9W-?<'1R``!;`5!E<FQ?27!E<FQ?9&5S=')U8W1?
M;&5V96Q?<'1R`/<$<&5R;%]C;VYS=')U8W0``/$$<&5R;%]A;&QO8P``E@!0
M97)L7T=D;U]U;F1U;7!?<'1R`.T$4&5R;%]W:6XS,E]I;FET`'!E<FPU."YD
M;&P``"0!1V5T36]D=6QE1FEL94YA;65!``"T`$9R965,:6)R87)Y`"8!1V5T
M36]D=6QE2&%N9&QE00``2T523D5,,S(N9&QL``#7`$=E=%5S97).86UE00``
M041605!),S(N9&QL``"R`G-P<FEN=&8`N`)S=')C;7```,<"<W1R=&]K``"^
M`G-T<FQE;@``Q0)S=')S='(``&T`7U]P7U]E;G9I<F]N``"8`FUE;6UO=F4`
MP0)S=')N8W!Y`,`"<W1R;F-M<`#(`%]E<G)N;P``@@%?;6MD:7(``(X!7W!C
M='EP90`5`5]I<V-T>7!E``!A`%]?;6)?8W5R7VUA>```EP)M96UC<'D``)D"
M;65M<V5T``"9`5]R;61I<@``WP!?9FEN9&-L;W-E``#B`%]F:6YD;F5X=`#=
M`5]U;FQI;FL`X`!?9FEN9&9I<G-T``"_`5]S=')D=7``Q0%?<W1R;FEC;7``
M35-60U)4+F1L;```TP!?97AI=`!(`%]88W!T1FEL=&5R`$D"97AI=```9`!?
M7W!?7U]I;FET96YV`%@`7U]G971M86EN87)G<P`/`5]I;FET=&5R;0"#`%]?
M<V5T=7-E<FUA=&AE<G(``)T`7V%D:G5S=%]F9&EV``!J`%]?<%]?8V]M;6]D
M90``;P!?7W!?7V9M;V1E``"!`%]?<V5T7V%P<%]T>7!E``#*`%]E>&-E<'1?
M:&%N9&QE<C,``+<`7V-O;G1R;VQF<```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````4$%``$Q!0`#_____U*!``)]<
M```````````````````!````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````#``,````H``"`#@```$@``(`0
M````8```@````````````````````@`!````>```@`(```"0``"`````````
M```````````!`&4```"H``"````````````````````!``$```#```"`````
M```````````````!``````#8```````````````````````!``````#H````
M```````````````````!``````#X```````````````````````!```````(
M`0``F,,``&@%``````````````#)``"H"`````````````"HT0``(@``````
M````````(,$``'0"````````````````````````=`(T````5@!3`%\`5@!%
M`%(`4P!)`$\`3@!?`$D`3@!&`$\``````+T$[_X```$`````````````````
M`````#\````!````!``$``$```````````````````#4`0```0!3`'0`<@!I
M`&X`9P!&`&D`;`!E`$D`;@!F`&\```"P`0```0`P`#0`,``P`#``-`!B`#``
M```8`````0!#`&\`;0!M`&4`;@!T`',````@`````0!#`&\`;0!P`&$`;@!Y
M`$X`80!M`&4``````"@````!`$8`:0!L`&4`1`!E`',`8P!R`&D`<`!T`&D`
M;P!N```````@`````0!&`&D`;`!E`%8`90!R`',`:0!O`&X``````"`````!
M`$D`;@!T`&4`<@!N`&$`;`!.`&$`;0!E````)`````$`3`!E`&<`80!L`$,`
M;P!P`'D`<@!I`&<`:`!T````*`````$`3`!E`&<`80!L`%0`<@!A`&0`90!M
M`&$`<@!K`',``````"@````!`$\`<@!I`&<`:0!N`&$`;`!&`&D`;`!E`&X`
M80!M`&4````@`````0!0`'(`:0!V`&$`=`!E`$(`=0!I`&P`9````"`````!
M`%``<@!O`&0`=0!C`'0`3@!A`&T`90``````)`````$`4`!R`&\`9`!U`&,`
M=`!6`&4`<@!S`&D`;P!N````(`````$`4P!P`&4`8P!I`&$`;`!"`'4`:0!L
M`&0```!$`````0!6`&$`<@!&`&D`;`!E`$D`;@!F`&\``````"0`!````%0`
M<@!A`&X`<P!L`&$`=`!I`&\`;@````````2P!``````H````$````"`````!
M``@````````!```````````````!`````0``!@8&``0$!``"`@(``````$)"
M0@"=G9T`;FYN`(&!@0"QL;$`____`'-S<P"?GY\`6%A8`+*RL@#]_?T`:VMK
M`/S\_`#7U]<`%A86`-K:V@"6EI8`CHZ.`$9&1@#+R\L`"PL+`*"@H`#^_OX`
MR<G)`,'!P0`#`P,`$1$1`).3DP"SL[,`[N[N`/3T]`#CX^,`Y>7E`**BH@"Z
MNKH`KZ^O``<'!P!Q<7$`M;6U`/7U]0")B8D`BHJ*`#0T-`#HZ.@`-34U`%I:
M6@"WM[<`V-C8`-#0T``='1T`#`P,`(^/CP"^OKX`;6UM``D)"0";FYL`+R\O
M`,W-S0#9V=D`&1D9`$U-30!$1$0`4%!0`#P\/`!D9&0`PL+"`#(R,@`("`@`
M#0T-``\/#P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````%!04%!04%!04%!04%!00$!`35`(P5!,4-!041%
M+@$!`0$!`0$%`3P7%P$!$P$!`0$!`0$!%0$!)A4!`0\!`0$!`0$!`1,!$0$%
M-0$F`0$!`0$!`0$B$A`Q#P4!(`$!`0$!`0$!$`H@(A45+B$N`0$!`0$?("$0
M(A`C(R4F)P$!`0$E$!`0$!`0$!`0%T4!`0%!$!`0$!`0$!`0$!`7`0$!#Q`0
M%1`0$!`0$!`0`0$!`1(0$!,?$!`0$!`0!P$!`0$@$!`0`0\0$!`0$0$!`0$!
M!R`0"@$!!1`0$#$!`0$!`0$!`0$!`0%!!0\!`0$!`0$!`0$!`0$!`0$!`0$!
M`0&``0``P`$``.`#``#P`P``\`,``/`#``#@`P``P`$``(`!``"``0``@`,`
M`(`#````!P````<``(X/``#_'P``*````"````!``````0`(````````!```
M`````````````0````$````````!`0$``@("``,#`P`$!`0`!04%``8&!@`'
M!P<`"`@(``D)"0`*"@H`"PL+``P,#``-#0T`#@X.``\/#P`0$!``$1$1`!(2
M$@`3$Q,`%!04`!45%0`6%A8`%Q<7`!@8&``9&1D`&AH:`!L;&P`<'!P`'1T=
M`!X>'@`?'Q\`("`@`"$A(0`B(B(`(R,C`"0D)``E)24`)B8F`"<G)P`H*"@`
M*2DI`"HJ*@`K*RL`+"PL`"TM+0`N+BX`+R\O`#`P,``Q,3$`,C(R`#,S,P`T
M-#0`-34U`#8V-@`W-S<`.#@X`#DY.0`Z.CH`.SL[`#P\/``]/3T`/CX^`#\_
M/P!`0$``04%!`$)"0@!#0T,`1$1$`$5%10!&1D8`1T='`$A(2`!)24D`2DI*
M`$M+2P!,3$P`34U-`$Y.3@!/3T\`4%!0`%%140!24E(`4U-3`%145`!5554`
M5E96`%=75P!86%@`65E9`%I:6@!;6UL`7%Q<`%U=70!>7EX`7U]?`&!@8`!A
M86$`8F)B`&-C8P!D9&0`965E`&9F9@!G9V<`:&AH`&EI:0!J:FH`:VMK`&QL
M;`!M;6T`;FYN`&]O;P!P<'``<7%Q`')R<@!S<W,`='1T`'5U=0!V=G8`=W=W
M`'AX>`!Y>7D`>GIZ`'M[>P!\?'P`?7U]`'Y^?@!_?W\`@("``(&!@0""@H(`
M@X.#`(2$A`"%A84`AH:&`(>'AP"(B(@`B8F)`(J*B@"+BXL`C(R,`(V-C0".
MCHX`CX^/`)"0D`"1D9$`DI*2`).3DP"4E)0`E965`):6E@"7EY<`F)B8`)F9
MF0":FIH`FYN;`)R<G`"=G9T`GIZ>`)^?GP"@H*``H:&A`**BH@"CHZ,`I*2D
M`*6EI0"FIJ8`IZ>G`*BHJ`"IJ:D`JJJJ`*NKJP"LK*P`K:VM`*ZNK@"OKZ\`
ML+"P`+&QL0"RLK(`L[.S`+2TM`"UM;4`MK:V`+>WMP"XN+@`N;FY`+JZN@"[
MN[L`O+R\`+V]O0"^OKX`O[^_`,#`P`#!P<$`PL+"`,/#PP#$Q,0`Q<7%`,;&
MQ@#'Q\<`R,C(`,G)R0#*RLH`R\O+`,S,S`#-S<T`SL[.`,_/SP#0T-``T='1
M`-+2T@#3T],`U-34`-75U0#6UM8`U]?7`-C8V`#9V=D`VMK:`-O;VP#<W-P`
MW=W=`-[>W@#?W]\`X.#@`.'AX0#BXN(`X^/C`.3DY`#EY>4`YN;F`.?GYP#H
MZ.@`Z>GI`.KJZ@#KZ^L`[.SL`.WM[0#N[NX`[^_O`/#P\`#Q\?$`\O+R`//S
M\P#T]/0`]?7U`/;V]@#W]_<`^/CX`/GY^0#Z^OH`^_O[`/S\_`#]_?T`_O[^
M`/___P`T-#0\/#P\/#P\/#P\/#P\/#P\/#P\/#PL#`0$!`0$!%RTU-34U-34
MU-34U-S4U-34U-34U-34U+0T400$!`0$9,SL]/3T_/3\]/3T_/3\]/ST_/S\
M]/3LQ#11400$!`1DQ.3L]/3T]/3T]/3T]/3T]/3T]/3T[.R\-%%1400$!&3$
MY.SL[.3L[.SDY.3D[.SD[.3L[.SLY+PT45%1400$9+SD[.RLC*S4Q)24G)2,
MC)24E)R<G.S<O#1145%1401DO-SD[.3$492L9.2D3#0L7,3,4;34Y-R\-%%1
M45%1462\W.3D[.3D481TY(QLI)QLC+QTK-3DW+PT!`0$!`0$9+S<Y.3LY.2\
M48S4U(RLS'3,W*11Q.3<O#0$!`0$!`1DO-SDY.3DY-R,?)RT?(2<;,SDO'3$
MY-RT-`0$!`0$!%R\W-SDY.3DU)RD7)2,S#R49,R\C%'<U+0T!`0$!`0$9+34
MW-S<Y-R,C*PLO+3,6L1DG&R4I-S4M#0$!`0$!`1<M-3<W.3<W'24U$RD](P\
MU'24=)Q,W,RT-`0$!`0$!&2TU-S<W.3<=%'T=(3LS&3D?&RDM&RDU+0T!`0$
M!`0$9+3,W-S,?(R$M/S,Q/STM/R\9,RLA%&\K#0$!`0$!`1<M,S4S(RDW-SL
M_/S\_/ST_.RT[*Q\E%&L-`0$!`0$!%RLS,QLG/3\_/S\_/S\_/S\_/S\Q)2,
M4:PT!`0$!`0$7*S$O'SD_/S\_/S\_/S\_/S\_/SLS*Q1K#0$!`0$!`1<K+1,
MQ/S\_.ST_/S\_/S\_/S\_/2\4<2L-`0$!`0$!%RLM$S4_/STM-S\_/S\_/S\
M_/S\S%',Q*0T!`0$!`0$7*S$I%'\_/RTG/3\_/S\_/S\_/244<S$I"P$!`0$
M!`1<I*11A.S\_,QDM.S\_/S\_/S\U&RLS+RD-`0$!`0$!%RD9'2\]/S\Q%&$
MG.3\_/S\_.2,4<S,Q*0T!`0$!`0$7*1LC.3T_/R<4<Q1E.S\_/S\O'3,S,2\
MG"P$!`0$!`1<I*QD7&2DI%&LS,1TE.3T_.11O,S,Q+R<-`0$!`0$!%RDM+R\
MC%%1Q,3,S*Q1?'R4;'R\S,3$O)PL!`0$!`0$7)R\Q,3$Q,3$Q,3$Q,1145%1
MO,3$Q,2TG#0$!`0$!`14G+3$Q,3$Q,3$Q,3$Q,3$Q,3$Q,3$O+2<+`0$!`0$
M!%2<O,3$O+R\O+R\O+R\O+R\O+R\O+R\M)PL!`0$!`0$7)RTQ+RTM+2TM+2T
MM+2TM+2TM+2TM+2LG"P$!`0$!`14A)2<G)24E)24E)24E)24E)24E)24E)2$
M)`0$!`0$!$147%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%0T!`0$!`0$````/P``
M`!\````/````!P````,````!`````````#\````_````/P```#\````_````
M/P```#\````_````/P```#\````_````/P```#\````_````/P```#\````_
M````/P```#\````_````/P```#\````_````/P```#\```$``@`0$````0`(
M`&@%```!`"`@```!``@`J`@```(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!.0C$P`````,\ZUDD!````1CI<4&5R;%]04$U<4$%2
<+5!A8VME<BTP+CDY,5QM>6QD<EQP87(N<&1B````
